use 5.020;

use lib 'D:/Spp/perl-spp/lib';
use Spp qw(repl spp);

my $spp_file = $ARGV[0];
if ($spp_file) { spp($spp_file) } else { repl() }
